@@ -10,10 +10,6 @@
 
 #undef ENABLE_AUTH
 
-#undef USE_LIB_CRYPTO
-
-#undef ENABLE_IDENT
-
 #undef CONF_DIR
 
 #undef DATA_DIR
