@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include "masqmail.h"
@@ -29,7 +30,7 @@ gchar *prot_names[] = {
 };
 
 static gchar*
-string_base62(gchar * res, guint value, gchar len)
+string_base62(gchar *res, guint value, gchar len)
 {
 	static gchar base62_chars[] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 	gchar *p = res + len;
@@ -41,28 +42,16 @@ string_base62(gchar * res, guint value, gchar len)
 	return res;
 }
 
-static gint
-_g_list_addr_isequal(gconstpointer a, gconstpointer b)
-{
-	address *addr1 = (address *) a;
-	address *addr2 = (address *) b;
-	int ret;
-
-	if ((ret = strcasecmp(addr1->domain, addr2->domain)) == 0) {
-		return strcmp(addr1->local_part, addr2->local_part);
-	}
-	return ret;
-}
-
-/* accept message from anywhere.
-   A message from local is indicated by msg->recieved_host == NULL
-
-   The -t option: With the ACC_RCPT_FROM_HEAD flag the addrs found found
-   in To/Cc/Bcc headers are added to the recipient list.
+/*
+**  accept message from anywhere.
+**  A message from local is indicated by msg->recieved_host == NULL
+**
+**  The -t option: With the ACC_RCPT_FROM_HEAD flag the addrs found found
+**  in To/Cc/Bcc headers are added to the recipient list.
 */
 
 accept_error
-accept_message_stream(FILE * in, message * msg, guint flags)
+accept_message_stream(FILE *in, message *msg, guint flags)
 {
 	gchar *line, *line1;
 	int line_size = MAX_DATALINE;
@@ -131,7 +120,7 @@ accept_message_stream(FILE * in, message * msg, guint flags)
 			if (line1[0] == ' ' || line1[0] == '\t') {
 				/* continuation of 'folded' header: */
 				if (hdr) {
-					char* cp;
+					char *cp;
 					cp = g_strconcat(hdr->header, line1, NULL);
 					hdr->value = cp + (hdr->value - hdr->header);
 					free(hdr->header);
@@ -146,9 +135,14 @@ accept_message_stream(FILE * in, message * msg, guint flags)
 				if ((hdr = get_header(line1))) {
 					msg->hdr_list = g_list_append(msg->hdr_list, hdr);
 				} else {
-					/* if get_header() returns NULL, no header was recognized,
-					   so this seems to be the first data line of a broken mailer
-					   which does not send an empty line after the headers */
+					/*
+					**  if get_header() returns NULL,
+					**  no header was recognized,
+					**  so this seems to be the first
+					**  data line of a broken mailer
+					**  which does not send an empty
+					**  line after the headers
+					*/
 					in_headers = FALSE;
 					msg->data_list = g_list_prepend(msg->data_list, g_strdup(line1));
 				}
@@ -186,7 +180,7 @@ accept_message_stream(FILE * in, message * msg, guint flags)
 }
 
 accept_error
-accept_message_prepare(message * msg, guint flags)
+accept_message_prepare(message *msg, guint flags)
 {
 	struct passwd *passwd = NULL;
 	time_t rec_time = time(NULL);
@@ -290,10 +284,12 @@ accept_message_prepare(message * msg, guint flags)
 		}
 
 		if (!msg->return_path) {
-			/* TODO: do we still need this as we don't fetch
-			         mail anymore? */
-			/* this can happen for pop3 accept only and if no
-			   Return-Path: header was given */
+			/*
+			**  TODO: do we still need this as we don't fetch
+			**        mail anymore?
+			**  This can happen for pop3 accept only and if no
+			**  Return-Path: header was given
+			*/
 			GList *hdr_list;
 			header *hdr;
 
@@ -377,21 +373,13 @@ accept_message_prepare(message * msg, guint flags)
 		    msg->uid, for_string ? for_string : "", rec_timestamp());
 	} else {
 		/* received from remote */
-#ifdef ENABLE_IDENT
 		DEBUG(5) debugf("adding 'Received:' header (5)\n");
 		hdr = create_header(HEAD_RECEIVED,
-		    "Received: from %s (ident=%s)\n\tby %s with %s (%s %s)\n\tid %s%s; %s\n",
-		    msg->received_host, msg->ident ? msg->ident : "unknown",
+		    "Received: from %s\n\tby %s with %s (%s %s)\n\tid %s%s; %s\n",
+		    msg->received_host,
 		    conf.host_name, prot_names[msg->received_prot], PACKAGE,
 		    VERSION, msg->uid, for_string ? for_string : "",
 		    rec_timestamp());
-#else
-		hdr = create_header(HEAD_RECEIVED,
-		    "Received: from %s\n\tby %s with %s (%s %s)\n\tid %s%s; %s\n",
-		    msg->received_host, conf.host_name,
-		    prot_names[msg->received_prot], PACKAGE, VERSION,
-		    msg->uid, for_string ? for_string : "", rec_timestamp());
-#endif
 	}
 	msg->hdr_list = g_list_prepend(msg->hdr_list, hdr);
 
@@ -402,7 +390,7 @@ accept_message_prepare(message * msg, guint flags)
 }
 
 accept_error
-accept_message(FILE * in, message * msg, guint flags)
+accept_message(FILE *in, message *msg, guint flags)
 {
 	accept_error err;
 
