@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <pwd.h>
@@ -49,7 +50,7 @@ init_conf()
 	}
 }
 
-static gchar* true_strings[] = {
+static gchar *true_strings[] = {
 	"yes", "on", "true", NULL
 };
 
@@ -58,7 +59,7 @@ static gchar *false_strings[] = {
 };
 
 static gboolean
-parse_boolean(gchar * rval)
+parse_boolean(gchar *rval)
 {
 	gchar **str;
 
@@ -84,7 +85,7 @@ parse_boolean(gchar * rval)
 
 /* make a list from each line in a file */
 static GList*
-parse_list_file(gchar * fname)
+parse_list_file(gchar *fname)
 {
 	GList *list = NULL;
 	FILE *fptr;
@@ -111,7 +112,7 @@ parse_list_file(gchar * fname)
 
 /* given a semicolon separated string, this function makes a GList out of it. */
 GList*
-parse_list(gchar * line, gboolean read_file)
+parse_list(gchar *line, gboolean read_file)
 {
 	GList *list = NULL;
 	gchar buf[256];
@@ -142,14 +143,15 @@ parse_list(gchar * line, gboolean read_file)
 	return list;
 }
 
-/* Split the addrs at '@' into local_part and domain. Without an '@'
-   everything is local_part. Create address structs, which are put
-   into a list and returned.
-   This funktion is used for lists of addrs containing globbing chars (* and ?).
-   We don't need valid RFC821 addresses here, just patterns to match against.
+/*
+**  Split the addrs at '@' into local_part and domain. Without an '@'
+**  everything is local_part. Create address structs, which are put into a
+**  list and returned.  This funktion is used for lists of addrs containing
+**  globbing chars (* and ?).  We don't need valid RFC821 addresses here,
+**  just patterns to match against.
 */
 static GList*
-parse_address_glob_list(gchar * line, gboolean read_file)
+parse_address_glob_list(gchar *line, gboolean read_file)
 {
 	GList *plain_list = parse_list(line, read_file);
 	GList *node;
@@ -157,8 +159,8 @@ parse_address_glob_list(gchar * line, gboolean read_file)
 
 	foreach(plain_list, node) {
 		gchar *item = (gchar *) (node->data);
-		char* at;
-		char* p;
+		char *at;
+		char *p;
 		address *addr = calloc(1, sizeof(address));
 
 		for (p=item+strlen(item)-1; isspace(*p) || *p=='>'; p--) {
@@ -188,7 +190,7 @@ parse_address_glob_list(gchar * line, gboolean read_file)
 }
 
 static GList*
-parse_resolve_list(gchar * line)
+parse_resolve_list(gchar *line)
 {
 	GList *list;
 	GList *list_node;
@@ -220,7 +222,7 @@ parse_resolve_list(gchar * line)
 }
 
 static interface*
-parse_interface(gchar * line, gint def_port)
+parse_interface(gchar *line, gint def_port)
 {
 	gchar buf[256];
 	gchar *p, *q;
@@ -247,52 +249,8 @@ parse_interface(gchar * line, gint def_port)
 	return iface;
 }
 
-#ifdef ENABLE_IDENT  /* so far used for that only */
-static struct in_addr*
-parse_network(gchar * line, gint def_port)
-{
-	gchar buf[256];
-	gchar *p, *q;
-	struct in_addr addr, mask_addr, net_addr, *p_net_addr;
-	guint n;
-
-	DEBUG(9) fprintf(stderr, "parse_network: %s\n", line);
-
-	p = line;
-	q = buf;
-	while ((*p != '\0') && (*p != '/') && (q < buf + 255))
-		*(q++) = *(p++);
-	*q = '\0';
-
-	if ((addr.s_addr = inet_addr(buf)) == INADDR_NONE) {
-		fprintf(stderr, "'%s' is not a valid address (must be ip)\n", buf);
-		exit(1);
-	}
-
-	if (*p) {
-		guint i;
-		p++;
-		i = atoi(p);
-		if ((i >= 0) && (i <= 32))
-			n = i ? ~((1 << (32 - i)) - 1) : 0;
-		else {
-			fprintf(stderr, "'%d' is not a valid net mask (must be >= 0 and <= 32)\n", i);
-			exit(1);
-		}
-	} else
-		n = 0;
-
-	mask_addr.s_addr = htonl(n);
-	net_addr.s_addr = mask_addr.s_addr & addr.s_addr;
-
-	p_net_addr = g_malloc(sizeof(struct in_addr));
-	p_net_addr->s_addr = net_addr.s_addr;
-	return p_net_addr;
-}
-#endif
-
 static gboolean
-eat_comments(FILE * in)
+eat_comments(FILE *in)
 {
 	gint c;
 
@@ -311,7 +269,7 @@ eat_comments(FILE * in)
 
 /* after parsing, eat trailing character until LF */
 static gboolean
-eat_line_trailing(FILE * in)
+eat_line_trailing(FILE *in)
 {
 	gint c;
 
@@ -322,7 +280,7 @@ eat_line_trailing(FILE * in)
 }
 
 static gboolean
-eat_spaces(FILE * in)
+eat_spaces(FILE *in)
 {
 	gint c;
 
@@ -336,7 +294,7 @@ eat_spaces(FILE * in)
 }
 
 static gboolean
-read_lval(FILE * in, gchar * buf, gint size)
+read_lval(FILE *in, gchar *buf, gint size)
 {
 	gint c;
 	gchar *ptr = buf;
@@ -373,7 +331,7 @@ read_lval(FILE * in, gchar * buf, gint size)
 }
 
 static gboolean
-read_rval(FILE * in, gchar * buf, gint size)
+read_rval(FILE *in, gchar *buf, gint size)
 {
 	gint c;
 	gchar *ptr = buf;
@@ -421,7 +379,7 @@ read_rval(FILE * in, gchar * buf, gint size)
 }
 
 static gboolean
-read_statement(FILE * in, gchar * lval, gint lsize, gchar * rval, gint rsize)
+read_statement(FILE *in, gchar *lval, gint lsize, gchar *rval, gint rsize)
 {
 	gint c;
 
@@ -449,7 +407,7 @@ read_statement(FILE * in, gchar * lval, gint lsize, gchar * rval, gint rsize)
 }
 
 gboolean
-read_conf(gchar * filename)
+read_conf(gchar *filename)
 {
 	FILE *in;
 
@@ -506,8 +464,6 @@ read_conf(gchar * filename)
 			conf.local_addresses = parse_list(rval, TRUE);
 		else if (strcmp(lval, "not_local_addresses") == 0)
 			conf.not_local_addresses = parse_list(rval, TRUE);
-		else if (strcmp(lval, "local_nets") == 0)
-			conf.local_nets = parse_list(rval, FALSE);
 		else if (strcmp(lval, "do_save_envelope_to") == 0)
 			conf.do_save_envelope_to = parse_boolean(rval);
 		else if (strcmp(lval, "defer_all") == 0)
@@ -544,27 +500,12 @@ read_conf(gchar * filename)
 				g_free(node->data);
 			}
 			g_list_free(tmp_list);
-		} else if (strcmp(lval, "ident_trusted_nets") == 0) {
-#ifdef ENABLE_IDENT
-			GList *node;
-			GList *tmp_list = parse_list(rval, FALSE);
-
-			conf.ident_trusted_nets = NULL;
-			foreach(tmp_list, node) {
-				conf.ident_trusted_nets = g_list_append(conf.ident_trusted_nets, parse_network((gchar *) (node->data), 25));
-				g_free(node->data);
-			}
-			g_list_free(tmp_list);
-#else
-			logwrite(LOG_WARNING, "%s ignored: not compiled with ident support\n", lval);
-#endif
-		} else if ((strncmp(lval, "connect_route.", 14) == 0)
-		           || (strncmp(lval, "online_routes.", 14) == 0)) {
+		} else if (strncmp(lval, "query_routes.", 13) == 0) {
 			GList *file_list = parse_list(rval, FALSE);
-			table_pair *pair = create_pair(&(lval[14]), file_list);
-			conf.connect_routes = g_list_append(conf.connect_routes, pair);
-		} else if (strcmp(lval, "local_net_route") == 0) {
-			conf.local_net_routes = parse_list(rval, FALSE);
+			table_pair *pair = create_pair(lval+13, file_list);
+			conf.query_routes = g_list_append(conf.query_routes, pair);
+		} else if (strcmp(lval, "permanent_routes") == 0) {
+			conf.perma_routes = parse_list(rval, FALSE);
 		} else if (strcmp(lval, "online_query") == 0)
 			conf.online_query = g_strdup(rval);
 		else if (strcmp(lval, "do_queue") == 0)
@@ -613,13 +554,13 @@ read_conf(gchar * filename)
 		conf.warn_intervals = parse_list("1h;4h;8h;1d;2d;3d", FALSE);
 
 	if (!conf.local_hosts) {
-		char* shortname = strdup(conf.host_name);
-		char* p = strchr(shortname, '.');
+		char *shortname = strdup(conf.host_name);
+		char *p = strchr(shortname, '.');
 		if (p) {
 			*p = '\0';
 		}
 		/* we don't care if shortname and conf.host_name are the same */
-		char* local_hosts_str = g_strdup_printf("localhost;%s;%s", shortname, conf.host_name);
+		char *local_hosts_str = g_strdup_printf("localhost;%s;%s", shortname, conf.host_name);
 		conf.local_hosts = parse_list(local_hosts_str, FALSE);
 		free(shortname);
 		free(local_hosts_str);
@@ -630,7 +571,7 @@ read_conf(gchar * filename)
 }
 
 connect_route*
-read_route(gchar * filename, gboolean is_local_net)
+read_route(gchar *filename, gboolean is_perma)
 {
 	gboolean ok = FALSE;
 	FILE *in;
@@ -641,11 +582,11 @@ read_route(gchar * filename, gboolean is_local_net)
 	DEBUG(5) debugf("read_route, filename = %s\n", filename);
 
 	route->filename = g_strdup(filename);
-	route->name = g_strdup(filename);  /* quick hack */
+	route->name = route->filename;  /* quick hack */
 
 	route->expand_h_sender_address = TRUE;
 
-	route->is_local_net = is_local_net;
+	route->is_perma = is_perma;
 
 	route->do_pipelining = TRUE;
 
@@ -773,10 +714,8 @@ read_route(gchar * filename, gboolean is_local_net)
 
 	if (!route->resolve_list) {
 #ifdef ENABLE_RESOLVER
-		if (!is_local_net) {
-			route->resolve_list = g_list_append(route->resolve_list, resolve_dns_mx);
-			route->resolve_list = g_list_append(route->resolve_list, resolve_dns_a);
-		}
+		route->resolve_list = g_list_append(route->resolve_list, resolve_dns_mx);
+		route->resolve_list = g_list_append(route->resolve_list, resolve_dns_a);
 #endif
 		route->resolve_list = g_list_append(route->resolve_list, resolve_byname);
 	}
@@ -804,7 +743,7 @@ read_route(gchar * filename, gboolean is_local_net)
 }
 
 static void
-_g_list_free_all(GList * list)
+_g_list_free_all(GList *list)
 {
 	GList *node;
 	if (list) {
@@ -815,7 +754,7 @@ _g_list_free_all(GList * list)
 }
 
 void
-destroy_route(connect_route * r)
+destroy_route(connect_route *r)
 {
 	if (r->filename)
 		g_free(r->filename);
@@ -855,7 +794,7 @@ destroy_route(connect_route * r)
 }
 
 GList*
-read_route_list(GList * rf_list, gboolean is_local_net)
+read_route_list(GList *rf_list, gboolean is_perma)
 {
 	GList *list = NULL;
 	GList *node;
@@ -867,7 +806,7 @@ read_route_list(GList * rf_list, gboolean is_local_net)
 
 	foreach(rf_list, node) {
 		gchar *fname = (gchar *) (node->data);
-		connect_route *route = read_route(fname, is_local_net);
+		connect_route *route = read_route(fname, is_perma);
 		if (route)
 			list = g_list_append(list, route);
 		else
@@ -883,7 +822,7 @@ read_route_list(GList * rf_list, gboolean is_local_net)
 }
 
 void
-destroy_route_list(GList * list)
+destroy_route_list(GList *list)
 {
 	GList *node;
 
@@ -893,21 +832,3 @@ destroy_route_list(GList * list)
 	}
 	g_list_free(list);
 }
-
-connect_route*
-create_local_route()
-{
-	connect_route *route;
-
-	route = g_malloc(sizeof(connect_route));
-	if (!route) {
-		return NULL;
-	}
-	memset(route, 0, sizeof(connect_route));
-	route->is_local_net = TRUE;
-	route->name = g_strdup("default local_net_route");
-	route->expand_h_sender_address = TRUE;
-	route->resolve_list = g_list_append(NULL, resolve_byname);
-	route->connect_error_fail = TRUE;
-	return route;
-}
