@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2002 Oliver Kurth
-    Copyright (C) 2008, 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2002 Oliver Kurth
+**  Copyright (C) 2008, 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <fnmatch.h>
@@ -24,10 +25,13 @@
 #include "masqmail.h"
 #include "smtp_out.h"
 
-/* collect failed/defered rcpts for failure/warning messages */
-/* returns TRUE if either there are no failures or a failure message has been successfully sent */
+/*
+**  collect failed/defered rcpts for failure/warning messages
+**  returns TRUE if either there are no failures or a failure message has
+**  been successfully sent
+*/
 gboolean
-delivery_failures(message * msg, GList * rcpt_list, gchar * err_fmt, ...)
+delivery_failures(message *msg, GList *rcpt_list, gchar *err_fmt, ...)
 {
 	gboolean ok_fail = TRUE, ok_warn = TRUE;
 	time_t now = time(NULL);
@@ -69,7 +73,7 @@ _g_list_strcasecmp(gconstpointer a, gconstpointer b)
 }
 
 gboolean
-deliver_local_mbox(message* msg, GList* hdr_list, address* rcpt, address* env_addr)
+deliver_local_mbox(message *msg, GList *hdr_list, address *rcpt, address *env_addr)
 {
 	DEBUG(1) debugf("attempting to deliver %s with mbox\n", msg->uid);
 	if (append_file(msg, hdr_list, rcpt->local_part)) {
@@ -92,7 +96,7 @@ deliver_local_mbox(message* msg, GList* hdr_list, address* rcpt, address* env_ad
 }
 
 gboolean
-deliver_local_pipe(message* msg, GList* hdr_list, address* rcpt, address* env_addr)
+deliver_local_pipe(message *msg, GList *hdr_list, address *rcpt, address *env_addr)
 {
 	guint flags;
 
@@ -117,7 +121,7 @@ deliver_local_pipe(message* msg, GList* hdr_list, address* rcpt, address* env_ad
 }
 
 gboolean
-deliver_local_mda(message* msg, GList* hdr_list, address* rcpt, address* env_addr)
+deliver_local_mda(message *msg, GList *hdr_list, address *rcpt, address *env_addr)
 {
 	gboolean ok = FALSE;
 	gchar *cmd = g_malloc(256);
@@ -151,7 +155,7 @@ deliver_local_mda(message* msg, GList* hdr_list, address* rcpt, address* env_add
 }
 
 gboolean
-deliver_local(msg_out * msgout)
+deliver_local(msg_out *msgout)
 {
 	message *msg = msgout->msg;
 	GList *rcpt_list = msgout->rcpt_list;
@@ -173,9 +177,11 @@ deliver_local(msg_out * msgout)
 		address *ret_path = msg->return_path;
 		header *retpath_hdr, *envto_hdr;
 
-		/* we need a private copy of the hdr list because we add headers
-		   here that belong to the rcpt only. g_list_copy copies only
-		   the nodes, so it is safe to g_list_free it */
+		/*
+		**  we need a private copy of the hdr list because we add
+		**  headers here that belong to the rcpt only. g_list_copy
+		**  copies only the nodes, so it is safe to g_list_free it
+		*/
 		hdr_list = g_list_copy(msg->hdr_list);
 		retpath_hdr = create_header(HEAD_ENVELOPE_TO, "Envelope-to: %s\n", addr_string(env_addr));
 		envto_hdr = create_header(HEAD_RETURN_PATH, "Return-path: %s\n", addr_string(ret_path));
@@ -184,8 +190,10 @@ deliver_local(msg_out * msgout)
 		hdr_list = g_list_prepend(hdr_list, retpath_hdr);
 
 		if (rcpt->local_part[0] == '|') {
-			/* probably for expanded aliases, but why not done
-			   like with the mda? //meillo 2010-12-06 */
+			/*
+			**  probably for expanded aliases, but why not done
+			**  like with the mda? //meillo 2010-12-06
+			*/
 			if (deliver_local_pipe(msg, hdr_list, rcpt, env_addr)) {
 				ok = TRUE;
 			}
@@ -235,10 +243,13 @@ deliver_local(msg_out * msgout)
 	return ok;
 }
 
-/* make a list of rcpt's of a message that are local
-   return a new copy of the list */
+/*
+**  make a list of rcpt's of a message that are local
+**  return a new copy of the list
+*/
 void
-msg_rcptlist_local(GList * rcpt_list, GList ** p_local_list, GList ** p_nonlocal_list)
+msg_rcptlist_local(GList *rcpt_list, GList **p_local_list,
+		GList **p_nonlocal_list)
 {
 	GList *rcpt_node;
 
@@ -250,7 +261,7 @@ msg_rcptlist_local(GList * rcpt_list, GList ** p_local_list, GList ** p_nonlocal
 
 		/* search for local host list: */
 		foreach(conf.local_hosts, dom_node) {
-			if (strcasecmp(dom_node->data, rcpt->domain) == 0) {
+			if (fnmatch(dom_node->data, rcpt->domain, FNM_CASEFOLD)==0) {
 				*p_local_list = g_list_append(*p_local_list, rcpt);
 				DEBUG(5) debugf("<%s@%s> is local\n", rcpt->local_part, rcpt->domain);
 				break;
@@ -262,7 +273,8 @@ msg_rcptlist_local(GList * rcpt_list, GList ** p_local_list, GList ** p_nonlocal
 }
 
 gboolean
-deliver_msglist_host_pipe(connect_route * route, GList * msgout_list, gchar * host, GList * res_list)
+deliver_msglist_host_pipe(connect_route *route, GList *msgout_list,
+		gchar *host, GList *res_list)
 {
 	gboolean ok = TRUE;
 	GList *msgout_node;
@@ -329,12 +341,14 @@ deliver_msglist_host_pipe(connect_route * route, GList * msgout_list, gchar * ho
 	return ok;
 }
 
-/* deliver list of messages to one host and finishes them if the message was
-   delivered to at least one rcpt.
-   Returns TRUE if at least one msg was delivered to at least one rcpt.
+/*
+**  deliver list of messages to one host and finishes them if the message was
+**  delivered to at least one rcpt.
+**  Returns TRUE if at least one msg was delivered to at least one rcpt.
 */
 gboolean
-deliver_msglist_host_smtp(connect_route * route, GList * msgout_list, gchar * host, GList * res_list)
+deliver_msglist_host_smtp(connect_route *route, GList *msgout_list,
+		gchar *host, GList *res_list)
 {
 	gboolean ok = FALSE;
 	GList *msgout_node;
@@ -354,7 +368,10 @@ deliver_msglist_host_smtp(connect_route * route, GList * msgout_list, gchar * ho
 	}
 
 	if (route->wrapper) {
-		psb = smtp_out_open_child(route->wrapper, host);
+		psb = smtp_out_open_child(route->wrapper);
+		if (psb) {
+			psb->remote_host = host;
+		}
 	} else {
 		psb = smtp_out_open(host, port, res_list);
 	}
@@ -406,7 +423,7 @@ deliver_msglist_host_smtp(connect_route * route, GList * msgout_list, gchar * ho
 				msg_out *msgout = (msg_out *) (msgout_node->data);
 				smtp_out_mark_rcpts(psb, msgout->rcpt_list);
 
-				if (delivery_failures(msgout->msg, msgout->rcpt_list, "while connected with %s, the server replied\n\t%s", host, psb->buffer)) {
+				if (delivery_failures(msgout->msg, msgout->rcpt_list, "while connected with %s, the server replied\n\t%s", (route->wrapper) ? "<wrapper>" : host, psb->buffer)) {
 					deliver_finish(msgout);
 				}
 			}
@@ -433,7 +450,7 @@ deliver_msglist_host_smtp(connect_route * route, GList * msgout_list, gchar * ho
 
 		smtp_out_msg(psb, msg, msgout->return_path, msgout->rcpt_list, msgout->hdr_list);
 
-		ok_fail = delivery_failures(msg, msgout->rcpt_list, "while connected with %s, the server replied\n\t%s", host, psb->buffer);
+		ok_fail = delivery_failures(msg, msgout->rcpt_list, "while connected with %s, the server replied\n\t%s", (route->wrapper) ? "<wrapper>" : host, psb->buffer);
 
 		if ((psb->error == smtp_eof) || (psb->error == smtp_timeout)) {
 			/* connection lost */
@@ -464,7 +481,8 @@ deliver_msglist_host_smtp(connect_route * route, GList * msgout_list, gchar * ho
 }
 
 gboolean
-deliver_msglist_host(connect_route * route, GList * msgout_list, gchar * host, GList * res_list)
+deliver_msglist_host(connect_route *route, GList *msgout_list, gchar *host,
+		GList *res_list)
 {
 
 	if (route->pipe) {
@@ -477,10 +495,10 @@ deliver_msglist_host(connect_route * route, GList * msgout_list, gchar * host, G
 }
 
 /*
-  delivers messages in msgout_list using route
+** delivers messages in msgout_list using route
 */
 gboolean
-deliver_route_msgout_list(connect_route * route, GList * msgout_list)
+deliver_route_msgout_list(connect_route *route, GList *msgout_list)
 {
 	gboolean ok = FALSE;
 	GList *mo_ph_list;
@@ -490,7 +508,8 @@ deliver_route_msgout_list(connect_route * route, GList * msgout_list)
 
 	if (route->mail_host) {
 		/* this is easy... deliver everything to a smart host for relay */
-		return deliver_msglist_host(route, msgout_list, NULL, route->resolve_list);
+		return deliver_msglist_host(route, msgout_list, NULL,
+				route->resolve_list);
 	}
 
 	/* this is not easy... */
@@ -501,14 +520,16 @@ deliver_route_msgout_list(connect_route * route, GList * msgout_list)
 		return FALSE;
 	}
 
-	/* TODO: It would be nice to be able to fork for each host.
-	   We cannot do that yet because of complications with finishing the
-	   messages. Threads could be a solution because they use the same
-	   memory. But we are not thread safe yet...
-	 */
+	/*
+	**  TODO: It would be nice to be able to fork for each host.
+	**  We cannot do that yet because of complications with finishing the
+	**  messages. Threads could be a solution because they use the same
+	**  memory. But we are not thread safe yet...
+	*/
 	foreach(mo_ph_list, mo_ph_node) {
 		msgout_perhost *mo_ph = (msgout_perhost *) (mo_ph_node->data);
-		if (deliver_msglist_host(route, mo_ph->msgout_list, mo_ph->host, route->resolve_list)) {
+		if (deliver_msglist_host(route, mo_ph->msgout_list,
+				mo_ph->host, route->resolve_list)) {
 			ok = TRUE;
 		}
 		destroy_msgout_perhost(mo_ph);
@@ -518,11 +539,12 @@ deliver_route_msgout_list(connect_route * route, GList * msgout_list)
 }
 
 /*
-  calls route_prepare_msg()
-  delivers messages in msg_list using route by calling deliver_route_msgout_list()
+** calls route_prepare_msg()
+** delivers messages in msg_list using route by calling
+** deliver_route_msgout_list()
 */
 gboolean
-deliver_route_msg_list(connect_route * route, GList * msgout_list)
+deliver_route_msg_list(connect_route *route, GList *msgout_list)
 {
 	GList *msgout_list_deliver = NULL;
 	GList *msgout_node;
@@ -536,12 +558,16 @@ deliver_route_msg_list(connect_route * route, GList * msgout_list)
 		GList *rcpt_list_non_delivered = NULL;
 		GList *rcpt_node;
 
-		/* we have to delete already delivered rcpt's because a
-		   previous route may have delivered to it */
+		/*
+		**  we have to delete already delivered rcpt's because a
+		**  previous route may have delivered to it
+		*/
 		foreach(msgout_cloned->rcpt_list, rcpt_node) {
 			address *rcpt = (address *) (rcpt_node->data);
-			/* failed addresses already have been bounced;
-			   there should be a better way to handle those. */
+			/*
+			**  failed addresses already have been bounced;
+			**  there should be a better way to handle those.
+			*/
 			if (!addr_is_delivered(rcpt) && !addr_is_failed(rcpt)
 			    && !(rcpt->flags & ADDR_FLAG_LAST_ROUTE)) {
 				rcpt_list_non_delivered = g_list_append(rcpt_list_non_delivered, rcpt);
@@ -557,20 +583,23 @@ deliver_route_msg_list(connect_route * route, GList * msgout_list)
 
 		/* filter by allowed envelope sender */
 		if (!route_sender_is_allowed(route, msgout->msg->return_path)) {
+			DEBUG(6) debugf("sender `%s' is not allowed for this route\n", msgout->msg->return_path);
 			destroy_msg_out(msgout_cloned);
 			continue;
 		}
 
 		/* filter by allowed envelope rcpts */
-		GList* rcpt_list_allowed = NULL;
-		GList* rcpt_list_notallowed = NULL;
-		route_split_rcpts(route, msgout_cloned->rcpt_list, &rcpt_list_allowed, &rcpt_list_notallowed);
+		GList *rcpt_list_allowed = NULL;
+		GList *rcpt_list_notallowed = NULL;
+		route_split_rcpts(route, msgout_cloned->rcpt_list,
+				&rcpt_list_allowed, &rcpt_list_notallowed);
 		if (!rcpt_list_allowed) {
 			destroy_msg_out(msgout_cloned);
 			continue;
 		}
 
-		logwrite(LOG_NOTICE, "%s using '%s'\n", msgout->msg->uid, route->name);
+		logwrite(LOG_NOTICE, "%s using '%s'\n", msgout->msg->uid,
+				route->name);
 
 		g_list_free(msgout_cloned->rcpt_list);
 		msgout_cloned->rcpt_list = rcpt_list_allowed;
@@ -596,11 +625,12 @@ deliver_route_msg_list(connect_route * route, GList * msgout_list)
 	return ok;
 }
 
-/* copy pointers of delivered addresses to the msg's non_rcpt_list,
-   to make sure that they will not be delivered again.
+/*
+**  copy pointers of delivered addresses to the msg's non_rcpt_list,
+**  to make sure that they will not be delivered again.
 */
 void
-update_non_rcpt_list(msg_out * msgout)
+update_non_rcpt_list(msg_out *msgout)
 {
 	GList *rcpt_node;
 	message *msg = msgout->msg;
@@ -613,15 +643,16 @@ update_non_rcpt_list(msg_out * msgout)
 	}
 }
 
-/* after delivery attempts, we check if there are any rcpt addresses left in
-   the message. If all addresses have been completed, the spool files will be
-   deleted, otherwise the header spool will be written back. We never changed
-   the data spool, so there is no need to write that back.
-
-   returns TRUE if all went well.
+/*
+**  after delivery attempts, we check if there are any rcpt addresses left in
+**  the message. If all addresses have been completed, the spool files will be
+**  deleted, otherwise the header spool will be written back. We never changed
+**  the data spool, so there is no need to write that back.
+**
+**  returns TRUE if all went well.
 */
 gboolean
-deliver_finish(msg_out * msgout)
+deliver_finish(msg_out *msgout)
 {
 	GList *rcpt_node;
 	message *msg = msgout->msg;
@@ -629,18 +660,21 @@ deliver_finish(msg_out * msgout)
 
 	update_non_rcpt_list(msgout);
 
-	/* we NEVER made copies of the addresses, flags affecting addresses
-	   were always set on the original address structs */
+	/*
+	**  we NEVER made copies of the addresses, flags affecting addresses
+	**  were always set on the original address structs
+	*/
 	foreach(msg->rcpt_list, rcpt_node) {
 		address *rcpt = (address *) (rcpt_node->data);
 		if (!addr_is_finished_children(rcpt)) {
 			finished = FALSE;
 		} else {
-			/* if ALL children have been delivered, mark parent as
-			   delivered. if there is one or more not delivered,
-			   it must have failed, we mark the parent as failed
-			   as well.
-			 */
+			/*
+			**  if ALL children have been delivered, mark parent as
+			**  delivered. if there is one or more not delivered,
+			**  it must have failed, we mark the parent as failed
+			**  as well.
+			*/
 			if (addr_is_delivered_children(rcpt)) {
 				addr_mark_delivered(rcpt);
 			} else {
@@ -667,38 +701,45 @@ deliver_finish(msg_out * msgout)
 	return TRUE;
 }
 
-gboolean
-deliver_finish_list(GList * msgout_list)
-{
-	gboolean ok = TRUE;
-	GList *msgout_node;
-	foreach(msgout_list, msgout_node) {
-		msg_out *msgout = (msg_out *) (msgout_node->data);
-		if (!deliver_finish(msgout)) {
-			ok = FALSE;
-		}
-	}
-	return ok;
-}
-
-gboolean
-deliver_msgout_list_online(GList * msgout_list)
+int
+deliver_remote(GList *remote_msgout_list)
 {
+	int ok = TRUE;
+	GList *route_list = NULL;
+	GList *route_node;
 	GList *rf_list = NULL;
 	gchar *connect_name = NULL;
-	gboolean ok = FALSE;
-	GList *route_node;
-	GList *route_list;
 
+	if (!remote_msgout_list) {
+		return FALSE;
+	}
+
+	/* perma routes */
+	if (conf.perma_routes) {
+		DEBUG(5) debugf("processing perma_routes\n");
+
+		route_list = read_route_list(conf.perma_routes, TRUE);
+		foreach(route_list, route_node) {
+			connect_route *route = (connect_route *) (route_node->data);
+			if (!deliver_route_msg_list(route, remote_msgout_list)) {
+				ok = FALSE;
+			}
+		}
+		destroy_route_list(route_list);
+	}
+
+	/* query routes */
 	connect_name = online_query();
 	if (!connect_name) {
+		DEBUG(5) debugf("online query returned false\n");
 		return FALSE;
 	}
 
 	/* we are online! */
-	logwrite(LOG_NOTICE, "detected online configuration %s\n", connect_name);
+	DEBUG(5) debugf("processing query_routes\n");
+	logwrite(LOG_NOTICE, "detected online configuration `%s'\n", connect_name);
 
-	rf_list = (GList *) table_find(conf.connect_routes, connect_name);
+	rf_list = (GList *) table_find(conf.query_routes, connect_name);
 	if (!rf_list) {
 		logwrite(LOG_ALERT, "route list with name '%s' not found.\n", connect_name);
 		return FALSE;
@@ -710,33 +751,37 @@ deliver_msgout_list_online(GList * msgout_list)
 		return FALSE;
 	}
 
-	/* TODO: Should we stop if the mail was delivered? Dig deeper! */
 	foreach(route_list, route_node) {
 		connect_route *route = (connect_route *) (route_node->data);
 		/* TODO: ok gets overwritten */
-		ok = deliver_route_msg_list(route, msgout_list);
+		ok = deliver_route_msg_list(route, remote_msgout_list);
 	}
 	destroy_route_list(route_list);
+
 	return ok;
 }
 
 /*
-   This function searches in the list of rcpt addresses
-   for local and 'local net' addresses. Remote addresses
-   which are reachable only when online are treated specially
-   in another function.
+**  This function splits the list of rcpt addresses
+**  into local and remote addresses and processes them accordingly.
 */
 gboolean
-deliver_msg_list(GList * msg_list, guint flags)
+deliver_msg_list(GList *msg_list, guint flags)
 {
-	GList *msgout_list = create_msg_out_list(msg_list);
+	GList *msgout_list = NULL;
+	GList *msg_node;
 	GList *local_msgout_list = NULL;
-	GList *localnet_msgout_list = NULL;
-	GList *other_msgout_list = NULL;
+	GList *remote_msgout_list = NULL;
 	GList *msgout_node;
 	GList *alias_table = NULL;
 	gboolean ok = TRUE;
 
+	/* create msgout_list */
+	foreach(msg_list, msg_node) {
+		message *msg = (message *) msg_node->data;
+		msgout_list = g_list_append(msgout_list, create_msg_out(msg));
+	}
+
 	if (conf.alias_file) {
 		alias_table = table_read(conf.alias_file, ':');
 	}
@@ -746,7 +791,6 @@ deliver_msg_list(GList * msg_list, guint flags)
 		msg_out *msgout = (msg_out *) (msgout_node->data);
 		GList *rcpt_list;
 		GList *local_rcpt_list = NULL;
-		GList *localnet_rcpt_list = NULL;
 		GList *other_rcpt_list = NULL;
 
 		if (!spool_lock(msgout->msg->uid)) {
@@ -771,7 +815,9 @@ deliver_msg_list(GList * msg_list, guint flags)
 			rcpt_list = aliased_rcpt_list;
 		}
 
-		split_rcpts(rcpt_list, conf.local_nets, &local_rcpt_list, &localnet_rcpt_list, &other_rcpt_list);
+		/* split_rcpts(rcpt_list, NULL, &local_rcpt_list, NULL, &other_rcpt_list); */
+		local_rcpt_list = local_rcpts(rcpt_list);
+		other_rcpt_list = remote_rcpts(rcpt_list);
 		g_list_free(rcpt_list);
 
 		/* local recipients */
@@ -781,18 +827,11 @@ deliver_msg_list(GList * msg_list, guint flags)
 			local_msgout_list = g_list_append(local_msgout_list, local_msgout);
 		}
 
-		/* local net recipients */
-		if ((flags & DLVR_LAN) && localnet_rcpt_list) {
-			msg_out *localnet_msgout = clone_msg_out(msgout);
-			localnet_msgout->rcpt_list = localnet_rcpt_list;
-			localnet_msgout_list = g_list_append(localnet_msgout_list, localnet_msgout);
-		}
-
-		/* remote recipients (the rest), requires online delivery  */
+		/* remote recipients, requires online delivery  */
 		if ((flags & DLVR_ONLINE) && other_rcpt_list) {
-			msg_out *other_msgout = clone_msg_out(msgout);
-			other_msgout->rcpt_list = other_rcpt_list;
-			other_msgout_list = g_list_append(other_msgout_list, other_msgout);
+			msg_out *remote_msgout = clone_msg_out(msgout);
+			remote_msgout->rcpt_list = other_rcpt_list;
+			remote_msgout_list = g_list_append(remote_msgout_list, remote_msgout);
 		}
 	}
 
@@ -800,7 +839,7 @@ deliver_msg_list(GList * msg_list, guint flags)
 		destroy_table(alias_table);
 	}
 
-	/* actual delivery */
+	/* process local/remote msgout lists -> delivery */
 
 	if (local_msgout_list) {
 		DEBUG(5) debugf("local_msgout_list\n");
@@ -813,35 +852,13 @@ deliver_msg_list(GList * msg_list, guint flags)
 		destroy_msg_out_list(local_msgout_list);
 	}
 
-	if (localnet_msgout_list) {
-		GList *route_list = NULL;
-		GList *route_node;
-
-		DEBUG(5) debugf("localnet_msgout_list\n");
-		if (conf.local_net_routes) {
-			route_list = read_route_list(conf.local_net_routes, TRUE);
-		} else {
-			route_list = g_list_append(NULL, create_local_route());
-		}
-
-		foreach(route_list, route_node) {
-			connect_route *route = (connect_route *) (route_node->data);
-			if (!deliver_route_msg_list(route, localnet_msgout_list)) {
-				ok = FALSE;
-			}
-		}
-		destroy_msg_out_list(localnet_msgout_list);
-		destroy_route_list(route_list);
-	}
-
-	if (other_msgout_list) {
-		DEBUG(5) debugf("other_msgout_list\n");
-		if (!deliver_msgout_list_online(other_msgout_list)) {
-			ok = FALSE;
-		}
-		destroy_msg_out_list(other_msgout_list);
+	if (remote_msgout_list) {
+		DEBUG(5) debugf("remote_msgout_list\n");
+		deliver_remote(remote_msgout_list);
+		destroy_msg_out_list(remote_msgout_list);
 	}
 
+	/* unlock spool files */
 	foreach(msgout_list, msgout_node) {
 		msg_out *msgout = (msg_out *) (msgout_node->data);
 		if (spool_unlock(msgout->msg->uid)) {
@@ -849,20 +866,20 @@ deliver_msg_list(GList * msg_list, guint flags)
 		} else {
 			DEBUG(5) debugf("spool_unlock(%s) failed.\n", msgout->msg->uid);
 		}
-
 	}
-
 	destroy_msg_out_list(msgout_list);
 
 	return ok;
 }
 
 /*
-   deliver() is called when a message has just been received and should
-   be delivered immediately.
+**  deliver() is called when a message has just been received
+**  (mode_accept and smtp_in) and should be delivered immediately
+**  (neither -odq nor do_queue). Only this one message will be tried to
+**  deliver then.
 */
 gboolean
-deliver(message * msg)
+deliver(message *msg)
 {
 	gboolean ok;
 	GList *msg_list = g_list_append(NULL, msg);
