@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include "masqmail.h"
@@ -31,22 +32,22 @@ create_message()
 }
 
 /*
-   This function is currently (0.2.24) only used for client side SMTP
-   SIZE support (RFC 1870). The flag is_smtp is always true therefore.
-
-   Their definition of the message size in RFC 1870 is:
-
-       The message size is defined as the number of octets, including
-       CR-LF pairs, but not the SMTP DATA command's terminating dot
-       or doubled quoting dots, to be transmitted by the SMTP client
-       after receiving reply code 354 to the DATA command.
-
-   l_cnt (line count) covers '\r' characters which are not present in
-   masqmail's internal format. Dots are also not stuffed in the
-   internal format. Dot-stuffing is ignored in the size.
+**  This function is currently (0.2.24) only used for client side SMTP
+**  SIZE support (RFC 1870). The flag is_smtp is always true therefore.
+**
+**  Their definition of the message size in RFC 1870 is:
+**
+**      The message size is defined as the number of octets, including
+**      CR-LF pairs, but not the SMTP DATA command's terminating dot
+**      or doubled quoting dots, to be transmitted by the SMTP client
+**      after receiving reply code 354 to the DATA command.
+**
+**  l_cnt (line count) covers '\r' characters which are not present in
+**  masqmail's internal format. Dots are also not stuffed in the
+**  internal format. Dot-stuffing is ignored in the size.
 */
 gint
-msg_calc_size(message * msg, gboolean is_smtp)
+msg_calc_size(message *msg, gboolean is_smtp)
 {
 	GList *node;
 	gint l_cnt = 0;  /* line count (we need to add so many '\r' for SMTP) */
@@ -91,7 +92,7 @@ msg_calc_size(message * msg, gboolean is_smtp)
 }
 
 void
-msg_free_data(message * msg)
+msg_free_data(message *msg)
 {
 	GList *node;
 
@@ -106,7 +107,7 @@ msg_free_data(message * msg)
 }
 
 void
-destroy_message(message * msg)
+destroy_message(message *msg)
 {
 	GList *node;
 
@@ -149,7 +150,7 @@ destroy_message(message * msg)
 }
 
 void
-destroy_msg_list(GList * msg_list)
+destroy_msg_list(GList *msg_list)
 {
 	GList *msg_node;
 
@@ -161,24 +162,15 @@ destroy_msg_list(GList * msg_list)
 }
 
 msg_out*
-create_msg_out(message * msg)
+create_msg_out(message *msg)
 {
-	msg_out *msgout = NULL;
-
-	msgout = g_malloc(sizeof(msg_out));
-	if (msgout) {
-		msgout->msg = msg;
-		msgout->return_path = NULL;
-		msgout->rcpt_list = NULL;
-
-		msgout->hdr_list = NULL;
-		msgout->xtra_hdr_list = NULL;
-	}
+	msg_out *msgout = g_malloc0(sizeof(msg_out));
+	msgout->msg = msg;
 	return msgout;
 }
 
 msg_out*
-clone_msg_out(msg_out * msgout_orig)
+clone_msg_out(msg_out *msgout_orig)
 {
 	if (msgout_orig) {
 		msg_out *msgout = create_msg_out(msgout_orig->msg);
@@ -200,21 +192,8 @@ clone_msg_out(msg_out * msgout_orig)
 	return NULL;
 }
 
-GList*
-create_msg_out_list(GList * msg_list)
-{
-	GList *msgout_list = NULL;
-	GList *msg_node;
-
-	foreach(msg_list, msg_node) {
-		message *msg = (message *) (msg_node->data);
-		msgout_list = g_list_append(msgout_list, create_msg_out(msg));
-	}
-	return msgout_list;
-}
-
 void
-destroy_msg_out(msg_out * msgout)
+destroy_msg_out(msg_out *msgout)
 {
 	if (msgout) {
 		if (msgout->return_path)
@@ -234,7 +213,7 @@ destroy_msg_out(msg_out * msgout)
 }
 
 void
-destroy_msg_out_list(GList * msgout_list)
+destroy_msg_out_list(GList *msgout_list)
 {
 	GList *msgout_node;
 
