@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <sys/stat.h>
@@ -42,15 +43,17 @@ mix_arr(int *buf, int len)
 }
 
 GList*
-read_queue(gboolean do_readdata)
+read_queue(void)
 {
 	GList *msg_list = NULL;
 	glob_t gl;
 	gchar *pattern;
 	int i, *idx_arr;
 
-	/* Escaping the question marks prevents them from being
-	   interpreted as trigraphs */
+	/*
+	**  Escaping the question marks prevents them from being
+	**  interpreted as trigraphs
+	*/
 	pattern = g_strdup_printf("%s/input/?????\?-??\?-?\?-H", conf.spool_dir);
 	gl.gl_offs = 0;
 	glob(pattern, 0, NULL, &gl);
@@ -76,7 +79,7 @@ read_queue(gboolean do_readdata)
 
 		DEBUG(5) debugf("uid: %s\n", uid);
 
-		msg_list = g_list_append(msg_list, msg_spool_read(uid, do_readdata));
+		msg_list = g_list_append(msg_list, msg_spool_read(uid));
 
 		DEBUG(5) debugf("after read spool file for %s\n", uid);
 
@@ -92,7 +95,7 @@ queue_run()
 	gboolean ok = TRUE;
 
 	logwrite(LOG_NOTICE, "Starting queue run.\n");
-	msg_list = read_queue(FALSE);
+	msg_list = read_queue();
 	if (msg_list) {
 		ok = deliver_msg_list(msg_list, DLVR_ALL);
 		DEBUG(5) debugf("  deliver_msg_list() returned: %d\n", ok);
@@ -110,7 +113,7 @@ queue_run_online()
 	gboolean ok = TRUE;
 
 	logwrite(LOG_NOTICE, "Starting online queue run.\n");
-	msg_list = read_queue(FALSE);
+	msg_list = read_queue();
 	if (msg_list) {
 		ok = deliver_msg_list(msg_list, DLVR_ONLINE);
 		DEBUG(5) debugf("  deliver_msg_list() returned: %d\n", ok);
@@ -140,7 +143,7 @@ queue_list()
 	GList *msg_list;
 	GList *msg_node;
 
-	msg_list = read_queue(FALSE);
+	msg_list = read_queue();
 
 	if (msg_list == NULL) {
 		printf("mail queue is empty.\n");
@@ -189,7 +192,7 @@ queue_list()
 }
 
 gboolean
-queue_delete(gchar * uid)
+queue_delete(gchar *uid)
 {
 	gboolean hdr_ok = TRUE;
 	gboolean dat_ok = TRUE;
