@@ -1,19 +1,20 @@
-/*  MasqMail
-    Copyright (C) 2000 Oliver Kurth
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 2000 Oliver Kurth
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <signal.h>
@@ -24,7 +25,6 @@
 #include <ctype.h>
 
 #include "readsock.h"
-/*#include "masqmail.h"*/
 
 jmp_buf jmp_timeout;
 
@@ -59,7 +59,7 @@ alarm_off()
 }
 
 static void
-_read_chug(FILE * in)
+_read_chug(FILE *in)
 {
 	int c = 0;
 
@@ -70,7 +70,7 @@ _read_chug(FILE * in)
 }
 
 static int
-_read_line(FILE * in, char *buf, int buf_len, int timeout)
+_read_line(FILE *in, char *buf, int buf_len, int timeout)
 {
 	int p = 0;
 	int c = 0;
@@ -97,7 +97,7 @@ _read_line(FILE * in, char *buf, int buf_len, int timeout)
 }
 
 int
-read_sockline(FILE * in, char *buf, int buf_len, int timeout, unsigned int flags)
+read_sockline(FILE *in, char *buf, int buf_len, int timeout, unsigned int flags)
 {
 	int p = 0;
 
@@ -131,7 +131,8 @@ read_sockline(FILE * in, char *buf, int buf_len, int timeout, unsigned int flags
 }
 
 int
-read_sockline1(FILE * in, char **pbuf, int *buf_len, int timeout, unsigned int flags)
+read_sockline1(FILE *in, char **pbuf, int *buf_len, int timeout,
+		unsigned int flags)
 {
 	int p = 0, size = *buf_len;
 	char *buf;
@@ -148,8 +149,13 @@ read_sockline1(FILE * in, char **pbuf, int *buf_len, int timeout, unsigned int f
 		_read_chug(in);
 	}
 
-	if (!*pbuf)
-		*pbuf = g_malloc(size);
+	if (!*pbuf) {
+		*pbuf = (char *) malloc(size);
+		if (!*pbuf) {
+			fprintf(stderr, "Out of memory.\n");
+			exit(1);
+		}
+	}
 	buf = *pbuf;
 
 	while (1) {
