@@ -1,32 +1,33 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include "masqmail.h"
 #include "readsock.h"
 
 /*
-  I always forget these rfc numbers:
-  RFC 821  (SMTP)
-  RFC 1869 (ESMTP)
-  RFC 1870 (ESMTP SIZE)
-  RFC 2197 (ESMTP PIPELINE)
-  RFC 2554 (ESMTP AUTH)
+**  I always forget these rfc numbers:
+**  RFC 821  (SMTP)
+**  RFC 1869 (ESMTP)
+**  RFC 1870 (ESMTP SIZE)
+**  RFC 2197 (ESMTP PIPELINE)
+**  RFC 2554 (ESMTP AUTH)
 */
 
 
@@ -43,7 +44,7 @@ smtp_cmd smtp_cmds[] = {
 };
 
 static smtp_cmd_id
-get_id(const gchar * line)
+get_id(const gchar *line)
 {
 	gint i;
 	for (i = 0; i < SMTP_NUM_IDS; i++) {
@@ -74,13 +75,14 @@ get_size(gchar *line, unsigned long *msize) {
 }
 
 
-/* this is a quick hack: we expect the address to be syntactically correct
-   and containing the mailbox only, though we first check for size in
-   smtp_in().
-   Return false if address is too long.
+/*
+**  this is a quick hack: we expect the address to be syntactically correct
+**  and containing the mailbox only, though we first check for size in
+**  smtp_in().
+**  Return false if address is too long.
 */
 static gboolean
-get_address(gchar * line, gchar * addr)
+get_address(gchar *line, gchar *addr)
 {
 	gchar *p = line;
 	gchar *q = addr;
@@ -110,7 +112,7 @@ get_address(gchar * line, gchar * addr)
 }
 
 static smtp_connection*
-create_base(gchar * remote_host)
+create_base(gchar *remote_host)
 {
 	smtp_connection *base = g_malloc(sizeof(smtp_connection));
 	if (!base) {
@@ -130,7 +132,7 @@ create_base(gchar * remote_host)
 }
 
 static void
-smtp_printf(FILE * out, gchar * fmt, ...)
+smtp_printf(FILE *out, gchar *fmt, ...)
 {
 	va_list args;
 	va_start(args, fmt);
@@ -153,14 +155,14 @@ smtp_printf(FILE * out, gchar * fmt, ...)
 }
 
 void
-smtp_in(FILE * in, FILE * out, gchar * remote_host, gchar * ident)
+smtp_in(FILE *in, FILE *out, gchar *remote_host, gchar *ident)
 {
 	gchar *buffer;
 	smtp_cmd_id cmd_id;
 	message *msg = NULL;
 	smtp_connection *psc;
 	int len;
-	unsigned long size, msize;
+	unsigned long msize;
 
 	DEBUG(5) debugf("smtp_in entered, remote_host = %s\n", remote_host);
 
@@ -351,10 +353,11 @@ smtp_in(FILE * in, FILE * out, gchar * remote_host, gchar * ident)
 				DEBUG(1) debugf("queuing forced by configuration or option.\n");
 			} else {
 				pid = fork();
-				if (pid == 0) {
-					_exit(deliver(msg));
-				} else if (pid < 0) {
+				if (pid < 0) {
 					logwrite(LOG_ALERT, "could not fork for delivery, id = %s\n", msg->uid);
+				} else if (pid == 0) {
+					/* FIXME: most likely inverted exit code */
+					_exit(deliver(msg));
 				}
 			}
 			psc->rcpt_seen = psc->from_seen = FALSE;
