@@ -1,29 +1,30 @@
-/* smtp_out.c
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
-
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
+/*
+**  smtp_out.c
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2010 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
 
 /*
-  I always forget these rfc numbers:
-  RFC 821  (SMTP)
-  RFC 1869 (ESMTP)
-  RFC 1870 (ESMTP SIZE)
-  RFC 2197 (ESMTP PIPELINE)
-  RFC 2554 (ESMTP AUTH)
+**  I always forget these rfc numbers:
+**  RFC 821  (SMTP)
+**  RFC 1869 (ESMTP)
+**  RFC 1870 (ESMTP SIZE)
+**  RFC 2197 (ESMTP PIPELINE)
+**  RFC 2554 (ESMTP AUTH)
 */
 
 #include "masqmail.h"
@@ -31,21 +32,13 @@
 #include "readsock.h"
 
 #ifdef ENABLE_AUTH
-
-#ifdef USE_LIB_CRYPTO
-#include <openssl/hmac.h>
-#include <openssl/md5.h>
-#include <openssl/evp.h>
-#else
 #include "md5/md5.h"
 #include "md5/hmac_md5.h"
-#endif
-
 #include "base64/base64.h"
 #endif
 
 void
-destroy_smtpbase(smtp_base * psb)
+destroy_smtpbase(smtp_base *psb)
 {
 	fclose(psb->in);
 	fclose(psb->out);
@@ -68,7 +61,7 @@ destroy_smtpbase(smtp_base * psb)
 }
 
 gchar*
-set_heloname(smtp_base * psb, gchar * default_name, gboolean do_correct)
+set_heloname(smtp_base *psb, gchar *default_name, gboolean do_correct)
 {
 	struct sockaddr_in sname;
 	int len = sizeof(struct sockaddr_in);
@@ -81,9 +74,12 @@ set_heloname(smtp_base * psb, gchar * default_name, gboolean do_correct)
 		if (host_entry) {
 			psb->helo_name = g_strdup(host_entry->h_name);
 		} else {
-			/* we failed to look up our own name. Instead of giving our local hostname,
-			   we may give our IP number to show the server that we are at least
-			   willing to be honest. For the really picky ones. */
+			/*
+			**  we failed to look up our own name. Instead of
+			**  giving our local hostname, we may give our IP
+			**  number to show the server that we are at least
+			**  willing to be honest. For the really picky ones.
+			*/
 			DEBUG(5) debugf("failed to look up own host name.\n");
 			psb->helo_name = g_strdup_printf("[%s]", inet_ntoa(sname.sin_addr));
 		}
@@ -98,7 +94,7 @@ set_heloname(smtp_base * psb, gchar * default_name, gboolean do_correct)
 #ifdef ENABLE_AUTH
 
 gboolean
-set_auth(smtp_base * psb, gchar * name, gchar * login, gchar * secret)
+set_auth(smtp_base *psb, gchar *name, gchar *login, gchar *secret)
 {
 	if ((strcasecmp(name, "CRAM-MD5") == 0) || (strcasecmp(name, "LOGIN") == 0)) {
 		psb->auth_name = g_strdup(name);
@@ -144,7 +140,7 @@ create_smtpbase(gint sock)
 }
 
 static gboolean
-read_response(smtp_base * psb, int timeout)
+read_response(smtp_base *psb, int timeout)
 {
 	gint buf_pos = 0;
 	gchar code[5];
@@ -178,7 +174,7 @@ read_response(smtp_base * psb, int timeout)
 }
 
 static gboolean
-check_response(smtp_base * psb, gboolean after_data)
+check_response(smtp_base *psb, gboolean after_data)
 {
 	char c = psb->buffer[0];
 
@@ -199,7 +195,7 @@ check_response(smtp_base * psb, gboolean after_data)
 }
 
 static gchar*
-get_response_arg(gchar * response)
+get_response_arg(gchar *response)
 {
 	gchar buf[SMTP_BUF_LEN];
 	gchar *p = response, *q = buf;
@@ -216,7 +212,7 @@ get_response_arg(gchar * response)
 }
 
 static gboolean
-check_helo_response(smtp_base * psb)
+check_helo_response(smtp_base *psb)
 {
 	gchar *ptr;
 
@@ -284,23 +280,23 @@ check_helo_response(smtp_base * psb)
 }
 
 /*
-We first try EHLO, but if it fails HELO in a second fall back try.
-This is what is requested by RFC 2821 (sec 3.2):
-
-	Once the server has sent the welcoming message and
-	the client has received it, the client normally sends
-	the EHLO command to the server, [...]
-	For a particular connection attempt, if the server
-	returns a "command not recognized" response to EHLO,
-	the client SHOULD be able to fall back and send HELO.
-
-Up to and including version 0.3.0 masqmail used ESMTP only if the
-string ``ESMTP'' appeared within the server's greeting message. This
-made it impossible to use AUTH with servers that would send odd
-greeting messages.
+**  We first try EHLO, but if it fails HELO in a second fall back try.
+**  This is what is requested by RFC 2821 (sec 3.2):
+**
+**      Once the server has sent the welcoming message and
+**      the client has received it, the client normally sends
+**      the EHLO command to the server, [...]
+**      For a particular connection attempt, if the server
+**      returns a "command not recognized" response to EHLO,
+**      the client SHOULD be able to fall back and send HELO.
+**
+**  Up to and including version 0.3.0 masqmail used ESMTP only if the
+**  string ``ESMTP'' appeared within the server's greeting message. This
+**  made it impossible to use AUTH with servers that would send odd
+**  greeting messages.
 */
 static gboolean
-smtp_helo(smtp_base * psb, gchar * helo)
+smtp_helo(smtp_base *psb, gchar *helo)
 {
 	fprintf(psb->out, "EHLO %s\r\n", helo);
 	fflush(psb->out);
@@ -318,8 +314,10 @@ smtp_helo(smtp_base * psb, gchar * helo)
 		return FALSE;
 	}
 
-	/* our guess that server understands EHLO could have been wrong,
-	   try again with HELO */
+	/*
+	**  our guess that server understands EHLO could have been wrong,
+	**  try again with HELO
+	*/
 
 	fprintf(psb->out, "HELO %s\r\n", helo);
 	fflush(psb->out);
@@ -338,7 +336,7 @@ smtp_helo(smtp_base * psb, gchar * helo)
 }
 
 static void
-smtp_cmd_mailfrom(smtp_base * psb, address * return_path, guint size)
+smtp_cmd_mailfrom(smtp_base *psb, address *return_path, guint size)
 {
 	if (psb->use_size) {
 		fprintf(psb->out, "MAIL FROM:%s SIZE=%d\r\n", addr_string(return_path), size);
@@ -355,7 +353,7 @@ smtp_cmd_mailfrom(smtp_base * psb, address * return_path, guint size)
 }
 
 static void
-smtp_cmd_rcptto(smtp_base * psb, address * rcpt)
+smtp_cmd_rcptto(smtp_base *psb, address *rcpt)
 {
 	fprintf(psb->out, "RCPT TO:%s\r\n", addr_string(rcpt));
 	fflush(psb->out);
@@ -363,15 +361,15 @@ smtp_cmd_rcptto(smtp_base * psb, address * rcpt)
 }
 
 static void
-send_data_line(smtp_base * psb, gchar * data)
+send_data_line(smtp_base *psb, gchar *data)
 {
-	/* According to RFC 821 each line should be terminated with CRLF.
-	   Since a dot on a line itself marks the end of data, each line
-	   beginning with a dot is prepended with another dot.
-	 */
+	/*
+	**  According to RFC 821 each line should be terminated with CRLF.
+	**  Since a dot on a line itself marks the end of data, each line
+	**  beginning with a dot is prepended with another dot.
+	*/
 	gchar *ptr;
-	gboolean new_line = TRUE;  /* previous versions assumed that each item was exactly one line.
-	                              This is no longer the case */
+	gboolean new_line = TRUE;  /* previous versions assumed that each item was exactly one line.  This is no longer the case */
 
 	ptr = data;
 	while (*ptr) {
@@ -394,7 +392,7 @@ send_data_line(smtp_base * psb, gchar * data)
 }
 
 static void
-send_header(smtp_base * psb, GList * hdr_list)
+send_header(smtp_base *psb, GList *hdr_list)
 {
 	GList *node;
 	gint num_hdrs = 0;
@@ -420,7 +418,7 @@ send_header(smtp_base * psb, GList * hdr_list)
 }
 
 static void
-send_data(smtp_base * psb, message * msg)
+send_data(smtp_base *psb, message *msg)
 {
 	GList *node;
 	gint num_lines = 0;
@@ -443,7 +441,7 @@ send_data(smtp_base * psb, message * msg)
 }
 
 void
-smtp_out_mark_rcpts(smtp_base * psb, GList * rcpt_list)
+smtp_out_mark_rcpts(smtp_base *psb, GList *rcpt_list)
 {
 	GList *rcpt_node;
 	for (rcpt_node = g_list_first(rcpt_list); rcpt_node; rcpt_node = g_list_next(rcpt_node)) {
@@ -460,7 +458,7 @@ smtp_out_mark_rcpts(smtp_base * psb, GList * rcpt_list)
 }
 
 void
-smtp_out_log_failure(smtp_base * psb, message * msg)
+smtp_out_log_failure(smtp_base *psb, message *msg)
 {
 	gchar *err_str;
 
@@ -485,7 +483,7 @@ smtp_out_log_failure(smtp_base * psb, message * msg)
 }
 
 smtp_base*
-smtp_out_open(gchar * host, gint port, GList * resolve_list)
+smtp_out_open(gchar *host, gint port, GList *resolve_list)
 {
 	smtp_base *psb;
 	gint sock;
@@ -513,26 +511,24 @@ smtp_out_open(gchar * host, gint port, GList * resolve_list)
 }
 
 smtp_base*
-smtp_out_open_child(gchar * cmd, char* host)
+smtp_out_open_child(gchar *cmd)
 {
 	smtp_base *psb;
 	gint sock;
 
 	DEBUG(5) debugf("smtp_out_open_child entered, cmd = %s\n", cmd);
-	psb->remote_host = host;
 	sock = child(cmd);
-	if (sock > 0) {
-		psb = create_smtpbase(sock);
-		psb->remote_host = NULL;
-
-		return psb;
+	if (sock <= 0) {
+		return NULL;
 	}
+	psb = create_smtpbase(sock);
+	psb->remote_host = NULL;
 
-	return NULL;
+	return psb;
 }
 
 gboolean
-smtp_out_rset(smtp_base * psb)
+smtp_out_rset(smtp_base *psb)
 {
 	gboolean ok;
 
@@ -552,7 +548,7 @@ smtp_out_rset(smtp_base * psb)
 #ifdef ENABLE_AUTH
 
 static gboolean
-smtp_out_auth_cram_md5(smtp_base * psb)
+smtp_out_auth_cram_md5(smtp_base *psb)
 {
 	gboolean ok = FALSE;
 
@@ -567,21 +563,13 @@ smtp_out_auth_cram_md5(smtp_base * psb)
 			guchar digest[16], *reply64, *reply;
 			gchar digest_string[33];
 			gint i;
-#ifdef USE_LIB_CRYPTO
-			unsigned int digest_len;
-#endif
 
 			DEBUG(5) debugf("smtp_out_auth_cram_md5():\n");
 			DEBUG(5) debugf("  encoded challenge = %s\n", chall64);
 			DEBUG(5) debugf("  decoded challenge = %s, size = %d\n", chall, chall_size);
 			DEBUG(5) debugf("  secret = %s\n", psb->auth_secret);
 
-#ifdef USE_LIB_CRYPTO
-			HMAC(EVP_md5(), psb->auth_secret, strlen(psb->auth_secret), chall, chall_size, digest, &digest_len);
-#else
 			hmac_md5(chall, chall_size, psb->auth_secret, strlen(psb->auth_secret), digest);
-#endif
-
 			for (i = 0; i < 16; i++)
 				sprintf(&(digest_string[i + i]), "%02x", (unsigned int) (digest[i]));
 			digest_string[32] = '\0';
@@ -612,7 +600,7 @@ smtp_out_auth_cram_md5(smtp_base * psb)
 }
 
 static gboolean
-smtp_out_auth_login(smtp_base * psb)
+smtp_out_auth_login(smtp_base *psb)
 {
 	gboolean ok = FALSE;
 	fprintf(psb->out, "AUTH LOGIN\r\n");
@@ -660,7 +648,7 @@ smtp_out_auth_login(smtp_base * psb)
 }
 
 gboolean
-smtp_out_auth(smtp_base * psb)
+smtp_out_auth(smtp_base *psb)
 {
 	gboolean ok = FALSE;
 	gint i = 0;
@@ -686,7 +674,7 @@ smtp_out_auth(smtp_base * psb)
 #endif
 
 gboolean
-smtp_out_init(smtp_base * psb, gboolean instant_helo)
+smtp_out_init(smtp_base *psb, gboolean instant_helo)
 {
 	gboolean ok;
 
@@ -718,7 +706,8 @@ smtp_out_init(smtp_base * psb, gboolean instant_helo)
 }
 
 gint
-smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt_list, GList * hdr_list)
+smtp_out_msg(smtp_base *psb, message *msg, address *return_path,
+		GList *rcpt_list, GList *hdr_list)
 {
 	gint i, size;
 	gboolean ok = TRUE;
@@ -748,8 +737,10 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 	}
 
 	if (ok) {
-		/* pretend the message is a bit larger,
-		   just in case the size calculation is buggy */
+		/*
+		**  pretend the message is a bit larger,
+		**  just in case the size calculation is buggy
+		*/
 		smtp_cmd_mailfrom(psb, return_path, psb->use_size ? size+SMTP_SIZE_ADD : 0);
 
 		if (!psb->use_pipelining) {
@@ -791,8 +782,10 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 			}
 		}
 
-		/* There is no point in going on if no recp.s were accpted.
-		   But we can check that at this point only if not pipelining: */
+		/*
+		**  There is no point in going on if no recp.s were accpted.
+		**  But we can check that at this point only if not pipelining:
+		*/
 		ok = (ok && (psb->use_pipelining || (rcpt_accept > 0)));
 		if (ok) {
 
@@ -802,17 +795,22 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 			DEBUG(4) debugf("C: DATA\r\n");
 
 			if (psb->use_pipelining) {
-				/* the first pl'ed command was MAIL FROM
-				   the last was DATA, whose response can be handled by the 'normal' code
-				   all in between were RCPT TO:
-				 */
+				/*
+				**  the first pl'ed command was MAIL FROM
+				**  the last was DATA, whose response can be
+				**  handled by the 'normal' code all in
+				**  between were RCPT TO:
+				*/
 				/* response to MAIL FROM: */
 				if ((ok = read_response(psb, SMTP_CMD_TIMEOUT))) {
 					if ((ok = check_response(psb, FALSE))) {
 
-						/* response(s) to RCPT TO:
-						   this is very similar to the sequence above for no pipeline
-						 */
+						/*
+						**  response(s) to RCPT TO:
+						**  this is very similar to
+						**  the sequence above for no
+						**  pipeline
+						*/
 						for (i = 0; i < rcpt_cnt; i++) {
 							if ((ok = read_response(psb, SMTP_CMD_TIMEOUT))) {
 								address *rcpt = g_list_nth_data(rcpt_list, i);
@@ -820,10 +818,12 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 									rcpt_accept++;
 									addr_mark_delivered(rcpt);
 								} else {
-									/* if server returned an error 4xx or 5xx for one recp. we
-									   may still try the others. But if it is a timeout, eof
-									   or unexpected response, it is more serious and we
-									   should give up. */
+									/*
+									** if server returned an error 4xx or 5xx for one recp. we
+									**  may still try the others. But if it is a timeout, eof
+									**  or unexpected response, it is more serious and we
+									**  should give up.
+									*/
 									if ((psb->error != smtp_trylater) &&
 										(psb->error != smtp_fail)) {
 										ok = FALSE;
@@ -886,9 +886,11 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 				         msg->uid, addr_string(rcpt), psb->remote_host);
 		}
 	} else {
-		/* if something went wrong,
-		   we have to unmark the rcpts prematurely marked as delivered
-		   and mark the status */
+		/*
+		**  if something went wrong,
+		**  we have to unmark the rcpts prematurely marked as
+		**  delivered and mark the status
+		*/
 		smtp_out_mark_rcpts(psb, rcpt_list);
 
 		/* log the failure: */
@@ -898,7 +900,7 @@ smtp_out_msg(smtp_base * psb, message * msg, address * return_path, GList * rcpt
 }
 
 gboolean
-smtp_out_quit(smtp_base * psb)
+smtp_out_quit(smtp_base *psb)
 {
 	fprintf(psb->out, "QUIT\r\n");
 	fflush(psb->out);
@@ -911,7 +913,8 @@ smtp_out_quit(smtp_base * psb)
 }
 
 gint
-smtp_deliver(gchar * host, gint port, GList * resolve_list, message * msg, address * return_path, GList * rcpt_list)
+smtp_deliver(gchar *host, gint port, GList *resolve_list, message *msg,
+		address *return_path, GList *rcpt_list)
 {
 	smtp_base *psb;
 	smtp_error err;
