@@ -1,20 +1,21 @@
-/*  MasqMail
-    Copyright (C) 1999-2001 Oliver Kurth
-    Copyright (C) 2008 markus schnalke <meillo@marmaro.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+/*
+**  MasqMail
+**  Copyright (C) 1999-2001 Oliver Kurth
+**  Copyright (C) 2008 markus schnalke <meillo@marmaro.de>
+**
+**  This program is free software; you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation; either version 2 of the License, or
+**  (at your option) any later version.
+**
+**  This program is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with this program; if not, write to the Free Software
+**  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 #include <fnmatch.h>
@@ -22,7 +23,7 @@
 #include "masqmail.h"
 
 table_pair*
-create_pair(gchar * key, gpointer value)
+create_pair(gchar *key, gpointer value)
 {
 	table_pair *pair;
 
@@ -34,7 +35,7 @@ create_pair(gchar * key, gpointer value)
 }
 
 table_pair*
-create_pair_string(gchar * key, gpointer value)
+create_pair_string(gchar *key, gpointer value)
 {
 	table_pair *pair;
 
@@ -46,7 +47,7 @@ create_pair_string(gchar * key, gpointer value)
 }
 
 table_pair*
-parse_table_pair(gchar * line, char delim)
+parse_table_pair(gchar *line, char delim)
 {
 	gchar buf[256];
 	gchar *p, *q;
@@ -72,7 +73,8 @@ parse_table_pair(gchar * line, char delim)
 }
 
 gpointer*
-table_find_func(GList * table_list, gchar * key, int (*cmp_func) (const char *, const char *))
+table_find_func(GList *table_list, gchar *key, int (*cmp_func) (const char *,
+		const char *))
 {
 	GList *node;
 
@@ -85,13 +87,13 @@ table_find_func(GList * table_list, gchar * key, int (*cmp_func) (const char *,
 }
 
 gpointer*
-table_find(GList * table_list, gchar * key)
+table_find(GList *table_list, gchar *key)
 {
 	return table_find_func(table_list, key, strcmp);
 }
 
 gpointer*
-table_find_case(GList * table_list, gchar * key)
+table_find_case(GList *table_list, gchar *key)
 {
 	return table_find_func(table_list, key, strcasecmp);
 }
@@ -103,13 +105,13 @@ fnmatch0(const char *pattern, const char *string)
 }
 
 gpointer*
-table_find_fnmatch(GList * table_list, gchar * key)
+table_find_fnmatch(GList *table_list, gchar *key)
 {
 	return table_find_func(table_list, key, fnmatch0);
 }
 
 GList*
-table_read(gchar * fname, gchar delim)
+table_read(gchar *fname, gchar delim)
 {
 	GList *list = NULL;
 	FILE *fptr;
@@ -137,7 +139,7 @@ table_read(gchar * fname, gchar delim)
 }
 
 void
-destroy_table(GList * table)
+destroy_table(GList *table)
 {
 	GList *node;
 
